import { Http } from "@angular/http";
import { Observable } from "rxjs/Observable";
import "rxjs/add/observable/of";
import { IServiceConfig } from "../service.config";
import { ReplicationJob, ReplicationRule } from "./interface";
import { RequestQueryParams } from "./RequestQueryParams";
/**
 * Define the service methods to handle the replication (rule and job) related things.
 *
 * @export
 * @abstract
 * @class ReplicationService
 */
export declare abstract class ReplicationService {
    /**
     * Get the replication rules.
     * Set the argument 'projectId' to limit the data scope to the specified project;
     * set the argument 'ruleName' to return the rule only match the name pattern;
     * if pagination needed, use the queryParams to add query parameters.
     *
     * @abstract
     * @param {(number | string)} [projectId]
     * @param {string} [ruleName]
     * @param {RequestQueryParams} [queryParams]
     * @returns {(Observable<ReplicationRule[]> | Promise<ReplicationRule[]> | ReplicationRule[])}
     *
     * @memberOf ReplicationService
     */
    abstract getReplicationRules(projectId?: number | string, ruleName?: string, queryParams?: RequestQueryParams): Observable<ReplicationRule[]> | Promise<ReplicationRule[]> | ReplicationRule[];
    /**
     * Get the specified replication rule.
     *
     * @abstract
     * @param {(number | string)} ruleId
     * @returns {(Observable<ReplicationRule> | Promise<ReplicationRule> | ReplicationRule)}
     *
     * @memberOf ReplicationService
     */
    abstract getReplicationRule(ruleId: number | string): Observable<ReplicationRule> | Promise<ReplicationRule> | ReplicationRule;
    /**
     * Create new replication rule.
     *
     * @abstract
     * @param {ReplicationRule} replicationRule
     * @returns {(Observable<any> | Promise<any> | any)}
     *
     * @memberOf ReplicationService
     */
    abstract createReplicationRule(replicationRule: ReplicationRule): Observable<any> | Promise<any> | any;
    /**
     * Update the specified replication rule.
     *
     * @abstract
     * @param {ReplicationRule} replicationRule
     * @returns {(Observable<any> | Promise<any> | any)}
     *
     * @memberOf ReplicationService
     */
    abstract updateReplicationRule(id: number, rep: ReplicationRule): Observable<any> | Promise<any> | any;
    /**
     * Delete the specified replication rule.
     *
     * @abstract
     * @param {(number | string)} ruleId
     * @returns {(Observable<any> | Promise<any> | any)}
     *
     * @memberOf ReplicationService
     */
    abstract deleteReplicationRule(ruleId: number | string): Observable<any> | Promise<any> | any;
    /**
     * Enable the specified replication rule.
     *
     * @abstract
     * @param {(number | string)} ruleId
     * @returns {(Observable<any> | Promise<any> | any)}
     *
     * @memberOf ReplicationService
     */
    abstract enableReplicationRule(ruleId: number | string, enablement: number): Observable<any> | Promise<any> | any;
    /**
     * Disable the specified replication rule.
     *
     * @abstract
     * @param {(number | string)} ruleId
     * @returns {(Observable<any> | Promise<any> | any)}
     *
     * @memberOf ReplicationService
     */
    abstract disableReplicationRule(ruleId: number | string): Observable<any> | Promise<any> | any;
    abstract replicateRule(ruleId: number | string): Observable<any> | Promise<any> | any;
    /**
     * Get the jobs for the specified replication rule.
     * Set query parameters through 'queryParams', support:
     *   - status
     *   - repository
     *   - startTime and endTime
     *   - page
     *   - pageSize
     *
     * @abstract
     * @param {(number | string)} ruleId
     * @param {RequestQueryParams} [queryParams]
     * @returns {(Observable<ReplicationJob> | Promise<ReplicationJob> | ReplicationJob)}
     *
     * @memberOf ReplicationService
     */
    abstract getJobs(ruleId: number | string, queryParams?: RequestQueryParams): Observable<ReplicationJob> | Promise<ReplicationJob> | ReplicationJob;
    /**
     * Get the log of the specified job.
     *
     * @abstract
     * @param {(number | string)} jobId
     * @returns {(Observable<string> | Promise<string> | string)}
     * @memberof ReplicationService
     */
    abstract getJobLog(jobId: number | string): Observable<string> | Promise<string> | string;
    abstract stopJobs(jobId: number | string): Observable<string> | Promise<string> | string;
}
/**
 * Implement default service for replication rule and job.
 *
 * @export
 * @class ReplicationDefaultService
 * @extends {ReplicationService}
 */
export declare class ReplicationDefaultService extends ReplicationService {
    private http;
    _ruleBaseUrl: string;
    _jobBaseUrl: string;
    _replicateUrl: string;
    constructor(http: Http, config: IServiceConfig);
    _isValidRule(rule: ReplicationRule): boolean;
    getReplicationRules(projectId?: number | string, ruleName?: string, queryParams?: RequestQueryParams): Observable<ReplicationRule[]> | Promise<ReplicationRule[]> | ReplicationRule[];
    getReplicationRule(ruleId: number | string): Observable<ReplicationRule> | Promise<ReplicationRule> | ReplicationRule;
    createReplicationRule(replicationRule: ReplicationRule): Observable<any> | Promise<any> | any;
    updateReplicationRule(id: number, rep: ReplicationRule): Observable<any> | Promise<any> | any;
    deleteReplicationRule(ruleId: number | string): Observable<any> | Promise<any> | any;
    replicateRule(ruleId: number | string): Observable<any> | Promise<any> | any;
    enableReplicationRule(ruleId: number | string, enablement: number): Observable<any> | Promise<any> | any;
    disableReplicationRule(ruleId: number | string): Observable<any> | Promise<any> | any;
    getJobs(ruleId: number | string, queryParams?: RequestQueryParams): Observable<ReplicationJob> | Promise<ReplicationJob> | ReplicationJob;
    getJobLog(jobId: number | string): Observable<string> | Promise<string> | string;
    stopJobs(jobId: number | string): Observable<any> | Promise<any> | any;
}
