import { Observable } from 'rxjs/Observable';
import { RequestQueryParams } from './RequestQueryParams';
import { Repository } from './interface';
import 'rxjs/add/observable/of';
import { Http } from '@angular/http';
import { IServiceConfig } from '../service.config';
/**
 * Define service methods for handling the repository related things.
 * Loose couple with project module.
 *
 * @export
 * @abstract
 * @class RepositoryService
 */
export declare abstract class RepositoryService {
    /**
     * List all the repositories in the specified project.
     * Specify the 'repositoryName' to only return the repositories which match the name pattern.
     * If pagination needed, set the following parameters in queryParams:
     *   'page': current page,
     *   'page_size': page size.
     *
     * @abstract
     * @param {(number | string)} projectId
     * @param {string} repositoryName
     * @param {RequestQueryParams} [queryParams]
     * @returns {(Observable<Repository> | Promise<Repository> | Repository)}
     *
     * @memberOf RepositoryService
     */
    abstract getRepositories(projectId: number | string, repositoryName?: string, queryParams?: RequestQueryParams): Observable<Repository> | Promise<Repository> | Repository;
    /**
     * Update description of specified repository.
     *
     * @abstract
     * @param {number | string} projectId
     * @param {string} repoName
     * @returns {(Observable<Repository> | Promise<Repository> | Repository)}
     *
     * @memberOf RepositoryService
     */
    abstract updateRepositoryDescription(repoName: string, description: string): Observable<any> | Promise<any> | any;
    /**
     * DELETE the specified repository.
     *
     * @abstract
     * @param {string} repositoryName
     * @returns {(Observable<any> | Promise<any> | any)}
     *
     * @memberOf RepositoryService
     */
    abstract deleteRepository(repositoryName: string): Observable<any> | Promise<any> | any;
}
/**
 * Implement default service for repository.
 *
 * @export
 * @class RepositoryDefaultService
 * @extends {RepositoryService}
 */
export declare class RepositoryDefaultService extends RepositoryService {
    private http;
    private config;
    constructor(http: Http, config: IServiceConfig);
    getRepositories(projectId: number | string, repositoryName?: string, queryParams?: RequestQueryParams): Observable<Repository> | Promise<Repository> | Repository;
    updateRepositoryDescription(repositoryName: string, description: string, queryParams?: RequestQueryParams): Observable<any> | Promise<any> | any;
    deleteRepository(repositoryName: string): Observable<any> | Promise<any> | any;
}
